Install
========

Pre-requisites
----------------

Before installing this library `almaqso`, please ensure that you have the following software installed on your system:

- Python (verified with version 3.13, however, you may use other Python 3.x versions)
- `CASA <https://casa.nrao.edu/>`_ (version 6.6.1 or later is recommended) with ALMA pipeline.
- `analysisUtilites <https://zenodo.org/records/17252072>`_ (latest version)

Installation
----------------
You can install the `almaqso` library using `pip`:

.. code-block:: bash

    pip install almaqso

This will install the latest version of `almaqso` along with its dependencies.